Skip to contents

This wrapper function standardizes the import of the Comprehensive Data (CD) output file from Field to Market Fieldprint Platform version 4. This function is specifically designed for version 4 output files.

Usage

read_ftm_cd_v4(file, sheet = "Report Data")

Arguments

file

.xlsx comprehensive data output file as exported from Fieldprint Platform v4

sheet

the sheet of the .xlsx file to read (default = "Report Data")

Value

tidy data.frame (tibble)

Details

The original name of an .xlsx CD file may be formatted like "MM-DD-YYYY-####_Comprehensive_Data_My_Farm.xlsx". Regardless, the read_ftm_cd_v4() function looks for the sheet "Report Data", as exported from the Fieldprint Platform version 4.

**Important:** This function is only compatible with version 4 output files.

Examples

if (FALSE) { # \dontrun{
raw_cd <- read_ftm_cd_v4("data-raw/12-09-2022-1234_Comprehensive_Data_Candyland_Farms.xlsx")
} # }