read_ftm_cd_v4
read_ftm_cd_v4.RdThis wrapper function standardizes the import of the Comprehensive Data (CD) output file from Field to Market Fieldprint Platform version 4. This function is specifically designed for version 4 output files.
Details
The original name of an .xlsx CD file may be formatted like "MM-DD-YYYY-####_Comprehensive_Data_My_Farm.xlsx". Regardless, the read_ftm_cd_v4() function looks for the sheet "Report Data", as exported from the Fieldprint Platform version 4.
**Important:** This function is only compatible with version 4 output files.